require 'spec_helper'

describe 'dcm4chee::service' do
  let(:basedir)      { '/usr/local/dcm4chee' }
  let(:init_script)  { "#{basedir}/bin/dcm4chee_init_solaris.sh" }
  let(:svc_manifest) { '/lib/svc/manifest/application/dcm4chee.xml' }
  let(:params)       { {:basedir => basedir} }

  it { should contain_file(init_script).with(
    :content => %r{^DCM4CHEE_BASEDIR="#{basedir}"$},
    :owner   => 'root',
    :group   => 'root',
    :mode    => '0755'
  )}

  it { should contain_file(svc_manifest).with(
    :content => %r{exec='#{init_script} start'},
    :owner   => 'root',
    :group   => 'root',
    :mode    => '0644'
  )}

  it { should contain_exec('manifest_import').with(
    :command     => '/usr/sbin/svcadm restart svc:/system/manifest-import && while sleep 1; do /usr/bin/svcs dcm4chee && break; done',
    :logoutput   => 'on_failure',
    :refreshonly => true,
    :subscribe   => [ "File[#{init_script}]", "File[#{svc_manifest}]" ]
  )}

  it { should contain_service('dcm4chee').with(
    :ensure    => 'running',
    :enable    => true,
    :subscribe => 'Exec[manifest_import]'
  )}
end
